pub enum CodeActionTriggerKind {
Invoked,
Automatic,
}Expand description
The reason why code actions were requested.
@since 3.17.0
Variants
Invoked
Code actions were explicitly requested by the user or by an extension.
Automatic
Code actions were requested automatically.
This typically happens when current selection in a file changes, but can also be triggered when file content changes.