pub enum InsertTextMode {
AsIs,
AdjustIndentation,
}Expand description
How whitespace and indentation is handled during completion item insertion.
@since 3.16.0
Variants
AsIs
The insertion or replace strings is taken as it is. If the value is multi line the lines below the cursor will be inserted using the indentation defined in the string value. The client will not apply any kind of adjustments to the string.
AdjustIndentation
The editor adjusts leading whitespace of new lines so that they match the indentation up to the cursor of the line for which the item is accepted.
Consider a line like this: <2tabs>