pub struct ColorPresentation {
pub label: String,
pub text_edit: Option<TextEdit>,
pub additional_text_edits: Option<Vec<TextEdit>>,
}Fields
label: StringThe label of this color presentation. It will be shown on the color picker header. By default this is also the text that is inserted when selecting this color presentation.
text_edit: Option<TextEdit>An {@link TextEdit edit} which is applied to a document when selecting
this presentation for the color. When falsy the {@link ColorPresentation.label label}
is used.
additional_text_edits: Option<Vec<TextEdit>>An optional array of additional {@link TextEdit text edits} that are applied when selecting this color presentation. Edits must not overlap with the main {@link ColorPresentation.textEdit edit} nor with themselves.