pub struct InlineCompletionContext {
pub trigger_kind: InlineCompletionTriggerKind,
pub selected_completion_info: Option<SelectedCompletionInfo>,
}Expand description
Provides information about the context in which an inline completion was requested.
@since 3.18.0
Fields
trigger_kind: InlineCompletionTriggerKindDescribes how the inline completion was triggered.
selected_completion_info: Option<SelectedCompletionInfo>Provides information about the currently selected item in the autocomplete widget if it is visible.