pub struct InlineValueText {
pub range: Range,
pub text: String,
}Expand description
Returns inline value information as the complete text to be shown.
@since 3.17.0
Fields
range: RangeThe document range for which the inline value applies.
text: StringThe text of the inline value.