pub struct SemanticTokenModifiers(pub String);Expand description
A set of predefined token modifiers. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.
@since 3.16.0
Tuple Fields
0: StringImplementations
Sourceimpl SemanticTokenModifiers
impl SemanticTokenModifiers
pub const DECLARATION: &'static str = "declaration"
pub const DEFINITION: &'static str = "definition"
pub const READONLY: &'static str = "readonly"
pub const STATIC: &'static str = "static"
pub const DEPRECATED: &'static str = "deprecated"
pub const ABSTRACT: &'static str = "abstract"
pub const ASYNC: &'static str = "async"
pub const MODIFICATION: &'static str = "modification"
pub const DOCUMENTATION: &'static str = "documentation"
pub const DEFAULT_LIBRARY: &'static str = "defaultLibrary"